asr.gs
======

.. automodule:: asr.gs

   
   
   .. rubric:: Functions

   
   .. autofunction:: bz_with_band_extremums
   .. autofunction:: evacdiff
   .. autofunction:: gaps
   .. autofunction:: get_1bz_k
   .. autofunction:: get_gap_info
   .. autofunction:: vacuumlevels
   .. autofunction:: webpanel
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: GapsResult
      :members:
   .. autoclass:: Result
      :members:
   .. autoclass:: VacuumLevelResults
      :members:
   
   

   
   
   